package com.lonepulse.droidballet.widget;

/*
 * #%L
 * DroidBallet
 * %%
 * Copyright (C) 2013 Lonepulse
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

import android.view.View;

import com.lonepulse.droidballet.registry.MotionListenerRegistry;
import com.lonepulse.droidballet.registry.MotionViewRegistry;

/**
 * <p>The common policy implemented by a <b>motion views</b>.
 * 
 * @version 1.0.0
 * 
 * @author <a href="mailto:lahiru@lonepulse.com">Lahiru Sahan Jayasinghe</a>
 */
public interface MotionView {
	
	/**
	 * <p>Registers this {@link View} with an implementation of {@link MotionListenerRegistry}; 
	 * to register with the default implementation, which is {@link MotionViewRegistry}, 
	 * use the following code:</p>
	 * 
	 * {@code MotionViewRegistry.INSTANCE.register(this);}
	 * 
	 * @since 1.0.0
	 */
	public abstract void register();
	
	/**
	 * <p>Unregisters this {@link View} with an implementation of {@link MotionListenerRegistry};
	 * to unregister with the default implementation, which is {@link MotionViewRegistry}, 
	 * use the following code:</p>
	 * 
	 * {@code MotionViewRegistry.INSTANCE.register(this}
	 * 
	 * @since 1.0.0
	 */
	public abstract void unregister();
}
